package
Version:
v0.0.0-...-2b0ec13
Opens a new window with list of versions in this module.
Published: May 26, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type MatchModel struct {
gorm.Model
Winner string `json:"winner"`
Loser string `json:"loser"`
WinnerGain uint `json:"winner_gain"`
LoserLoss uint `json:"loser_loss"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.